body {
	font-family: sans-serif;
	margin-left : 50px;
	margin-right : 50px;
}

hr {
	color : white;
	width : 1px;
	position : absolute;
}

h1	{
	font-size: 22pt;
	padding-bottom : 10px;
	background-color : transparent;
	color : #00008B;
}
	
h2	{
	font-size: 14pt;
	color: #8B0000;
	background-color: #FFEBCD;
	margin-top: 20px;
	padding: 10px;
	border: thin;
	border-color : Black;
	border-style : solid;
}

h4 {
	border : thin;
	border-style : solid;
	padding: 10px;
	width: 50%;
	background-color: #FFEBCD;
}
em {
	text-decoration : underline;
	font-style : normal;
	}
	dt {
	background-color : #F0FFFF;
}
dd {
	border-left : thick;
	border-left-color : Red;
	border-left-style : solid;
	padding-left: 10px;
	padding-top: 5px;
	margin-bottom: 10px;
}
table	{
	background-color : Gray;
	}
	
TH	{
	background: #DCDCDC;
	padding : 5px;
	}
	td {
	background-color : white;
	padding-right : 10px;
	padding-left: 10px;
}
A:link	{	text-decoration: none;
		color: #007676;
	}
A:visited {	text-decoration: none;
		color: #006060;
	}
A:hover	{
	text-decoration: none;
	color: green;
	background-color: #F5F5DC;
	}
